LessThan

Enum LessThan 

pub enum LessThan {
    Lt(Duration),
    Lte(Duration),
}

Variants



Lt(Duration)

lt stipulates that the field must be less than the specified value of the google.protobuf.Duration type, exclusive. If the field’s value is greater than or equal to the specified value, an error message will be generated.

message MyDuration {
   // must be less than 5s
   google.protobuf.Duration value = 1 \[(buf.validate.field).duration.lt = { seconds: 5 }\];
}


Lte(Duration)

lte indicates that the field must be less than or equal to the specified value of the google.protobuf.Duration type, inclusive. If the field’s value is greater than the specified value, an error message will be generated.

message MyDuration {
   // must be less than or equal to 10s
   google.protobuf.Duration value = 1 \[(buf.validate.field).duration.lte = { seconds: 10 }\];
}

Implementations

Source

impl LessThan

pub fn encode(&self, buf: &mut impl BufMut)

Encodes the message to a buffer.

pub fn merge( field: &mut Option<LessThan>, tag: u32, wire_type: WireType, buf: &mut impl Buf, ctx: DecodeContext, ) -> Result<(), DecodeError>

Decodes an instance of the message from a buffer, and merges it into self.

pub fn encoded_len(&self) -> usize

Returns the encoded length of the message without a length delimiter.