FieldMaskRules

Struct FieldMaskRules 

pub struct FieldMaskRules {
    pub const: Option<FieldMask>,
    pub in: Vec<String>,
    pub not_in: Vec<String>,
    pub example: Vec<FieldMask>,
}
FieldMaskRules describe rules applied exclusively to the google.protobuf.FieldMask well-known type.

Fields

const: Option<FieldMask>

const dictates that the field must match the specified value of the google.protobuf.FieldMask type exactly. If the field’s value deviates from the specified value, an error message will be generated.

message MyFieldMask {
   // value must equal \["a"\]
   google.protobuf.FieldMask value = 1 [(buf.validate.field).field_mask.const = {
       paths: \["a"\]
   }];
}
in: Vec<String>

in requires the field value to only contain paths matching specified values or their subpaths. If any of the field value’s paths doesn’t match the rule, an error message is generated. See: https://protobuf.dev/reference/protobuf/google.protobuf/#field-mask

message MyFieldMask {
   //  The `value` FieldMask must only contain paths listed in `in`.
   google.protobuf.FieldMask value = 1 [(buf.validate.field).field_mask = {
       in: \["a", "b", "c.a"\]
   }];
}
not_in: Vec<String>

not_in requires the field value to not contain paths matching specified values or their subpaths. If any of the field value’s paths matches the rule, an error message is generated. See: https://protobuf.dev/reference/protobuf/google.protobuf/#field-mask

message MyFieldMask {
   //  The `value` FieldMask shall not contain paths listed in `not_in`.
   google.protobuf.FieldMask value = 1 [(buf.validate.field).field_mask = {
       not_in: \["forbidden", "immutable", "c.a"\]
   }];
}
example: Vec<FieldMask>

example specifies values that the field may have. These values SHOULD conform to other rules. example values will not impact validation but may be used as helpful guidance on how to populate the given field.

message MyFieldMask {
   google.protobuf.FieldMask value = 1 [
     (buf.validate.field).field_mask.example = { paths: \["a", "b"\] },
     (buf.validate.field).field_mask.example = { paths: \["c.a", "d"\] },
   ];
}