SInt32Rules

Struct SInt32Rules 

pub struct SInt32Rules {
    pub const: Option<i32>,
    pub in: Vec<i32>,
    pub not_in: Vec<i32>,
    pub example: Vec<i32>,
    pub less_than: Option<LessThan>,
    pub greater_than: Option<GreaterThan>,
}
SInt32Rules describes the rules applied to sint32 values.

Fields

const: Option<i32>

const requires the field value to exactly match the specified value. If the field value doesn’t match, an error message is generated.

message MySInt32 {
   // value must equal 42
   sint32 value = 1 \[(buf.validate.field).sint32.const = 42\];
}
in: Vec<i32>

in requires the field value to be equal to one of the specified values. If the field value isn’t one of the specified values, an error message is generated.

message MySInt32 {
   // must be in list \[1, 2, 3\]
   sint32 value = 1 \[(buf.validate.field).sint32 = { in: [1, 2, 3\] }];
}
not_in: Vec<i32>

not_in requires the field value to not be equal to any of the specified values. If the field value is one of the specified values, an error message is generated.

message MySInt32 {
   // value must not be in list \[1, 2, 3\]
   sint32 value = 1 \[(buf.validate.field).sint32 = { not_in: [1, 2, 3\] }];
}
example: Vec<i32>

example specifies values that the field may have. These values SHOULD conform to other rules. example values will not impact validation but may be used as helpful guidance on how to populate the given field.

message MySInt32 {
   sint32 value = 1 [
     (buf.validate.field).sint32.example = 1,
     (buf.validate.field).sint32.example = -10
   ];
}
less_than: Option<LessThan>greater_than: Option<GreaterThan>

Implementations

Source

impl SInt32Rules

pub fn const(&self) -> i32

Returns the value of const, or the default value if const is unset.