pub struct UInt64Rules {
pub const: Option<u64>,
pub in: Vec<u64>,
pub not_in: Vec<u64>,
pub example: Vec<u64>,
pub less_than: Option<LessThan>,
pub greater_than: Option<GreaterThan>,
}Expand description
UInt64Rules describes the rules applied to uint64 values. These
rules may also be applied to the google.protobuf.UInt64Value Well-Known-Type.
Fields
const: Option<u64>const requires the field value to exactly match the specified value. If
the field value doesn’t match, an error message is generated.
message MyUInt64 {
// value must equal 42
uint64 value = 1 \[(buf.validate.field).uint64.const = 42\];
}in: Vec<u64>in requires the field value to be equal to one of the specified values.
If the field value isn’t one of the specified values, an error message is
generated.
message MyUInt64 {
// must be in list \[1, 2, 3\]
uint64 value = 1 \[(buf.validate.field).uint64 = { in: [1, 2, 3\] }];
}not_in: Vec<u64>not_in requires the field value to not be equal to any of the specified
values. If the field value is one of the specified values, an error
message is generated.
message MyUInt64 {
// value must not be in list \[1, 2, 3\]
uint64 value = 1 \[(buf.validate.field).uint64 = { not_in: [1, 2, 3\] }];
}example: Vec<u64>example specifies values that the field may have. These values SHOULD
conform to other rules. example values will not impact validation
but may be used as helpful guidance on how to populate the given field.
message MyUInt64 {
uint64 value = 1 [
(buf.validate.field).uint64.example = 1,
(buf.validate.field).uint64.example = -10
];
}less_than: Option<LessThan>greater_than: Option<GreaterThan>Implementations